"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Polling = void 0;
const debug = require("debug");
const EventTransport_1 = require("./EventTransport");
class Polling extends EventTransport_1.EventTransport {
    constructor() {
        super(...arguments);
        this.log = debug("tg-io:polling");
    }
    async start(handler) {
        if (this.state === EventTransport_1.EventTransportState.Working) {
            return;
        }
        this.log("started");
        return new Promise((resolve, reject) => {
            this.handleUpdates(handler, resolve, reject).catch(reject);
        });
    }
    async handleUpdates(handler, onstop, onerror) {
        let offset;
        this.state = EventTransport_1.EventTransportState.Working;
        while (this.state === EventTransport_1.EventTransportState.Working) {
            let updates = (await this.api.callMethod("getUpdates", offset === undefined ? {} : { offset }));
            offset = (offset !== null && offset !== void 0 ? offset : 0) + updates.result.length;
            Promise.all(updates.result.map(async (update) => {
                return await handler.handle(update);
            })).catch(onerror);
        }
        onstop();
    }
    stop() {
        if (this.state !== EventTransport_1.EventTransportState.Working)
            return;
        this.log("stopped");
        this.state = EventTransport_1.EventTransportState.Stopped;
    }
}
exports.Polling = Polling;
